#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_ARECATCOMPATIBLE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_ARECATCOMPATIBLE_HPP_INCLUDED

#include <nt2/predicates/include/functions/scalar/arecatcompatible.hpp>

#endif
